#
# spec file for package librest
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   rest
%define sover   0
%define abi     1.0
%define abi_pkg 1_0
%define libname librest-%{abi_pkg}-%{sover}
Name:           librest
Version:        0.9.1
Release:        3.6
Summary:        Library to access RESTful web services
License:        LGPL-2.1-only
Group:          Development/Libraries/GNOME
URL:            http://git.gnome.org/browse/librest/
Source0:        http://download.gnome.org/sources/rest/0.9/%{_name}-%{version}.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM 0001-rest_proxy_call_sync-bail-out-if-no-payload.patch -- rest_proxy_call_sync: bail out if no payload
Patch0:         0001-rest_proxy_call_sync-bail-out-if-no-payload.patch
# PATCH-FIX-UPSTREAM 0002-Handle-some-potential-problems-in-parsing-oauth2-acc.patch -- Handle some potential problems in parsing oauth2 access tokens
Patch1:         0002-Handle-some-potential-problems-in-parsing-oauth2-acc.patch


BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(vapigen)

%description
This library was designed to make it easier to access web services that
claim to be "RESTful". A reasonable description is that a RESTful
service should have urls that represent remote objects, which methods
can then be called on.

It is comprised of two parts:

    * the first aims to make it easier to make requests by providing a
      wrapper around libsoup.
    * the second aids with XML parsing by wrapping libxml2.

%package -n %{libname}
Summary:        Library to access RESTful web services
Group:          System/Libraries
Recommends:     config(ca-certificates)
Obsoletes:      librest0 < %{version}-%{release}
Provides:       librest0 = %{version}-%{release}

%description -n %{libname}
This library was designed to make it easier to access web services that
claim to be "RESTful". A reasonable description is that a RESTful
service should have urls that represent remote objects, which methods
can then be called on.

It is comprised of two parts:

    * the first aims to make it easier to make requests by providing a
      wrapper around libsoup.
    * the second aids with XML parsing by wrapping libxml2.

%package -n typelib-1_0-Rest-%{abi_pkg}
Summary:        Library to access RESTful web services -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Rest-%{abi_pkg}
This library was designed to make it easier to access web services that
claim to be "RESTful". A reasonable description is that a RESTful
service should have urls that represent remote objects, which methods
can then be called on.

This package provides the GObject Introspection bindings for librest.

%package devel
Summary:        Library to access RESTful web services - Development Files
Group:          Development/Libraries/GNOME
Requires:       %{libname} = %{version}
Requires:       typelib-1_0-Rest-%{abi_pkg} = %{version}

%description devel
This library was designed to make it easier to access web services that
claim to be "RESTful". A reasonable description is that a RESTful
service should have urls that represent remote objects, which methods
can then be called on.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
# We should be able to pass both these (though just the first should be needed) - it fails the build however
#	-D ca_certificates=true \
#	-D ca_certificates_path=%%{_sysconfdir}/ssl/ca-bundle.pem \
%meson \
	-D ca_certificates=true \
	-D ca_certificates_path=%{_sysconfdir}/ssl/ca-bundle.pem \
	-D examples=false \
	-D vapi=true \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license COPYING
%doc AUTHORS README.md
%{_libdir}/librest-%{abi}.so.%{sover}
%{_libdir}/librest-%{abi}.so.%{sover}.*
%{_libdir}/librest-extras-%{abi}.so.%{sover}
%{_libdir}/librest-extras-%{abi}.so.%{sover}.*

%files -n typelib-1_0-Rest-%{abi_pkg}
%{_libdir}/girepository-1.0/Rest-%{abi}.typelib
%{_libdir}/girepository-1.0/RestExtras-%{abi}.typelib

%files devel
%{_libdir}/librest-%{abi}.so
%{_libdir}/librest-extras-%{abi}.so
%{_libdir}/pkgconfig/rest-%{abi}.pc
%{_libdir}/pkgconfig/rest-extras-%{abi}.pc
%{_datadir}/gir-1.0/*.gir
%{_includedir}/rest-%{abi}/
%doc %{_datadir}/doc/librest-%{abi}/
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/rest-1.0.deps
%{_datadir}/vala/vapi/rest-1.0.vapi
%{_datadir}/vala/vapi/rest-extras-1.0.deps
%{_datadir}/vala/vapi/rest-extras-1.0.vapi

%changelog
* Sun Feb 26 2023 Luciano Santos <luc14n0@opensuse.org>
- Replace python3-gi-docgen build requirement with the more
  reliable pkgconfig(gi-docgen).
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add patches to fix some minor issues that upstream have solved in
  a different way in git, but this should suffice for now for us:
  + 0001-rest_proxy_call_sync-bail-out-if-no-payload.patch:
    rest_proxy_call_sync: bail out if no payload.
  + 0002-Handle-some-potential-problems-in-parsing-oauth2-acc.patch:
    Handle some potential problems in parsing oauth2 access tokens.
* Sat Aug 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Stop passing soup2=false and tests=false to meson, follow the
  defaults.
- Pass vapi=true and add pkgconfig(vapigen) BuildRequires: Build
  vapi support.
- Pass ca_certificates=true and
  ca_certificates_path=%%{_sysconfdir}/ssl/ca-bundle.pem to meson.
* Mon Jun 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.9.1:
  + Removed RestAuth object.
  + Added an demo application to showcase librest.
  + Removed OAuth1 Proxy.
  + Added soupapiversion to pkg-config file in order to check the
    which soup version this library got built with.
  + Build against libsoup3 by default.
* Fri Jan 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.9.0:
  + New oauth2 proxy to accomplish pkce workflow with api endpoints
  + Introduced meson as buildsystem.
  + Introduced the possibility to build librest with soup-2.4 or
    soup-3.0
- Bump abi and abi_pkg to 1.0 and 1_0 following upstream changes.
- Add meson, gtk-doc, python3-gi-docgen and
  pkgconfig(json-glib-1.0) BuildRequires and meson macros, port to
  meson buildsystem.
- Use ldconfig_scriptlets macro for post(un) handling.
- Add pkgconfig(libsoup-3.0) BuildRequires and drop
  pkgconfig(libsoup-2.4) pkgconfig(libsoup-gnome-2.4)
  BuildRequires: Build with soup-3.0.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Oct 19 2017 dimstar@opensuse.org
- Update to version 0.8.1:
  + RestProxy: Set the payload after _upload.
  + proxycall: remove double-assign to status_{code,message}.
* Tue Apr 25 2017 jengelh@inai.de
- Use librest-0_7-0 as shared library name, similar to how it is
  done for libmwaw-0_3.
- Drop redundant %%clean section; use %%_smp_mflags for parallel
  build.
* Fri May  6 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Apr 18 2016 zaitor@opensuse.org
- Update to version 0.8.0:
  + build-sys: Set version to 0.8.0.
  + tests: Fix lastfm test.
  + tests/proxy-continuous:
  - Simplify the code.
  - Server chunks can be different from client ones.
  + oauth: Don't leak temp data in steal_oauth_params.
  + rest-xml-parser: Ignore text content at the top-level of a
    document.
  + rest-proxy-auth: Add rest_proxy_auth_cancel for cancelling
    authentication.
* Wed Mar 18 2015 zaitor@opensuse.org
- Update to version 0.7.93:
  + oauth: Add missing include.
  + xml-parser: Add missing break in switch statement.
  + Don't dump XML parsing errors to stderr/stdout by default.
  + Fix misc bugs in tests.
- Drop librest-missing-include.patch: Fixed upstream.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 0.7.92:
  + Bugs fixed: bgo#665716, bgo#708358, bgo#708359, bgo#728340,
    bgo#728952, bgo#728953, bgo#735919, bgo#735920, bgo#735921,
    bgo#735922.
- Add librest-missing-include.patch: Add missing includes.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 0.7.91:
  + Bugs fixed: bgo#702483, bgo#703103, bgo#703642, bgo#712231,
    bgo#712747.
* Wed Aug 28 2013 dimstar@opensuse.org
- Drop librest-fix-build-without-ca-certificates.patch: as
  identified in bnc#825903, this is not sufficient and needs more
  investigation / rewriting.
- Revert --without-ca-certificates configure option back to
  - -with-ca-certificates=/etc/ssl/ca-bundle.pem.
* Thu Jul 11 2013 dimstar@opensuse.org
- Add librest-fix-build-without-ca-certificates.patch: Fix build
  with configure --without-ca-certificates.
- Pass --without-ca-certificates to configure instead of
  - -with-ca-certificates=/etc/ssl/ca-bundle.pem (bnc#825903).
* Wed Aug 29 2012 dimstar@opensuse.org
- Update to version 0.7.90:
  + Allow to disable libsoup strict SSL check
  + Add username/password support
  + Several API additions
  + Build fixes
  + Fix some leaks.
* Wed May  9 2012 vuntz@opensuse.org
- Add baselibs.conf, as we need the 32bit package for
  gnome-online-account libraries.
* Fri Jan  6 2012 vuntz@opensuse.org
- Split typelib files into typelib-1_0-Rest-0_7 subpackage.
- Add typelib-1_0-Rest-0_7 Requires to devel subpackage.
- Change librest0 group from Development/Libraries/GNOME to
  System/Libraries.
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.7.12:
  + Build: Detect CA file location [bgo#663783]
  + proxy: Force all SSL certificates to be trusted [bgo#663783]
- Add config(ca-certificates) BuildRequires and Recommends in the
  shared library package.
- Pass --with-ca-certificates=/etc/ssl/ca-bundle.pem to configure.
* Sun Nov  6 2011 dimstar@opensuse.org
- Update to version 0.7.11:
  + oauth-proxy: Fix format string warning
  + oauth:
  - Add GType for OAuthSignatureMethod enum
  - Add property for signature type
  + Build fixes.
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 0.7.10:
  + Introduce rest_proxy_call_upload to provide progress feedback.
  + youtube-proxy: Added upload progress callbacks.
  + Added documentation to rest_proxy_call_upload.
  + bmc#13746: proxy-call: Allow customisation of data
    serialization.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.7.9:
  + Add "disable-cookies" construction property to RestProxy.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 0.7.8:
  + Add youtube proxy for uploaded video.
  + Fix introspection build.
- Drop librest-fix-introspection.patch: fixed upstream.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 0.7.7:
  + Fix a few introspection issues
  + oauth-proxy:
  - Use POST method to do OAuth 1.0 authentication.
  - Added 'signature-host' propery.
- Add librest-fix-introspection.patch: fix introspection build.
  Taken from upstream, commit e9c917.
* Thu Mar  3 2011 vuntz@opensuse.org
- Update to version 0.7.6:
  + API for manually constructing and outputting XML
- Changes from version 0.7.5:
  + Introspection build fixes
- Changes from version 0.7.4:
  + Add cookie support to rest-proxy.
  + proxy-call: Add continuous call mode
  + Various bug fixes.
- Changes from version 0.7.3:
  + Fix memory corruption in oauth-proxy-call.
- Changes from version 0.7.2:
  + post-twitter: use the correct URL endpoint
  + Plug leak.
- Changes from version 0.7.1:
  + Flickr: add upload support
  + Various bug fixes.
  + Improved documentation.
- Changes from version 0.7.0:
  + Remove FacebookProxy
  + Add Lastfm proxy
  + Add a oauth2 proxy
  + Add RestParam and RestParams types
  + Flickr proxy: Allow specifying the permissions required in the
    login url
  + Various bug fixes.
  + Improved documentation.
- Drop librest-fbconnect-url.patch: facebook features got removed
  upstream.
- Change BuildRequires to pkgconfig() ones: glib2-devel to
  glib-2.0, libsoup-devel to libsoup-2.4 and libsoup-gnome-2.4,
  libxml2-devel to libxml-2.0.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires to enable
  introspection.
- Update Url tag.
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 0.6.3:
  + Fix leaks.
  + Code cleanups.
- Changes from version 0.6.2:
  + Add introspection support.
  + Mark GErrors which shouldn't be freed as const.
  + Add oauth_proxy_call_parse_token_reponse to parse token
    responses.
  + Build system fixes.
- Remove explicit Requires of devel packages in devel subpackage:
  they will be added automatically the pkgconfig()-way.
* Wed Mar 17 2010 pascal.bleser@opensuse.org
- (re?)add librest-fbconnect-url.patch from Moblin:Factory to fix
  the build of bisho
- some spec file tidying: more explicit %%files listing to avoid
  unintended/unnoticed major changes
- use %%soname and %%abi defines throughout to spec to ease
  future maintenance
* Mon Mar 15 2010 awafaa@opensuse.org
- Fix spec to comply with shared libraries policy.
* Thu Feb  4 2010 abockover@novell.com
- Rename to librest, provide/obsolete rest
* Tue Dec 29 2009 glin@novell.com
- Add librest-fbconnect-url.patch to add a new fbconnect url
  funciton for facebook
* Fri Nov  6 2009 glin@novell.com
- Upddate to 0.6.1
  * 四  7月 16 2009 Gary Lin <glin@novell.com> 0.520090716
- Update to commit ff4561e2a8c38f49127f6e3b2ce7c238a29e1571
  * 四  7月 09 2009 Gary Lin <glin@novell.com> 0.420090709
- Update to commit e9a71922f5997243c45dfaaff21dd9b4a6340ca3
  * 四  7月 09 2009 Gary Lin <glin@novell.com> 0.420090709
- Update to commit 41f91eec3d26a2514c4bc310b90829cd2d14ed4a
* Fri Jun 12 2009 <michael.meeks@novell.com> 0.420090612
- Update to commit 92e1871d3181a73a780f588689733f25e3df5b48
* Tue May 19 2009 vuntz@novell.com
- Use configure macro to get the right options.
* Mon May 18 2009 <michael.meeks@novell.com> 0.3.120090518
- Update to commit e49d8730bfb277af59732822e78535ef37e29b6c
* Mon May 11 2009 <michael.meeks@novell.com> 0.3.120090511
- Update to commit 153d2e8c5cc3452a7275c7ea7fa6abe8750cde8b
